@@ -25,19 +25,6 @@
 #include <openssl/md5.h>
 #include <openssl/evp.h>
 
-typedef struct _TDNF_METALINK_URLS_ {
-    char *url;
-    struct _TDNF_METALINK_URLS_ *next;
-} TDNF_METALINK_URLS;
-
-typedef struct _TDNF_METALINK_FILE_{
-    char *filename;
-    int   type;
-    /* raw digest value, not ascii hex digest */
-    unsigned char digest[EVP_MAX_MD_SIZE];
-    TDNF_METALINK_URLS *urls;
-} TDNF_METALINK_FILE;
-
 //clean.c
 uint32_t
 TDNFCopyEnabledRepos(
@@ -242,10 +229,22 @@ TDNFCurlErrorIsFatal(
 );
 
 //remoterepo.c
+uint32_t
+TDNFCheckHexDigest(
+    const char *hex_digest,
+    int digest_length
+    );
+
+uint32_t
+TDNFChecksumFromHexDigest(
+    const char *hex_digest,
+    unsigned char *ppdigest
+    );
+
 uint32_t
 TDNFCheckRepoMDFileHashFromMetalink(
     char *pszFile,
-    TDNF_METALINK_FILE *ml_file
+    TDNF_ML_CTX *ml_ctx
     );
 
 uint32_t
@@ -253,7 +252,7 @@ TDNFParseAndGetURLFromMetalink(
     PTDNF pTdnf,
     const char *pszRepo,
     const char *pszFile,
-    TDNF_METALINK_FILE **ml_file
+    TDNF_ML_CTX *ml_ctx
     );
 
 uint32_t
@@ -608,11 +607,6 @@ TDNFReadFileToStringArray(
     );
 
 //repo.c
-void
-TDNFFreeMetalinkUrlsList(
-    TDNF_METALINK_URLS *metalink_urls
-    );
-
 uint32_t
 TDNFInitRepoFromMetadata(
     Repo *pRepo,
@@ -1151,4 +1145,62 @@ TDNFListInternal(
     TDNF_PKG_DETAIL nDetail
     );
 
+// metalink.c
+
+uint32_t
+TDNFMetalinkParseFile(
+    TDNF_ML_CTX *ml_ctx,
+    int fd,
+    const char *filename
+    );
+
+void
+TDNFMetalinkFree(
+    TDNF_ML_CTX *ml_ctx
+    );
+
+uint32_t
+TDNFXmlParseData(
+    TDNF_ML_CTX *ml_ctx,
+    xmlNode *node,
+    const char *filename
+    );
+
+uint32_t
+TDNFParseFileTag(
+    TDNF_ML_CTX *ml_ctx,
+    xmlNode *node,
+    const char *filename
+    );
+
+uint32_t
+TDNFParseHashTag(
+    TDNF_ML_CTX *ml_ctx,
+    xmlNode *node
+    );
+
+
+uint32_t
+TDNFParseUrlTag(
+    TDNF_ML_CTX *ml_ctx,
+    xmlNode *node
+    );
+
+// list.c
+void 
+TDNFSortListOnPreference(
+    TDNF_ML_LIST** headUrl
+);
+
+uint32_t
+TDNFAppendList(
+    TDNF_ML_LIST** head_ref,
+    void *new_data
+);
+
+void 
+TDNFDeleteList(
+    TDNF_ML_LIST** head_ref,
+    TDNF_ML_FREE_FUNC free_func
+);
 #endif /* __CLIENT_PROTOTYPES_H__ */
